==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/task.prune_request.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');
  if ( !defined('__XF_ALLOW_TASK') )
  die('Running tasks has not been allowed by XF-Core!');

/**
* @package lbbackend
*/
class XFTask_prune_request extends XFTask {
public $version = 0x01;
protected $trace = array();

  public function setup(){
  return array(
  'default_interval'=>3600,
  'default_active'=>true
  );
  }

  public function execute(){
  $reported = array(0);
  $sche = XF::sql_query("SELECT ur_data FROM ".XF::tbl('user_request')." WHERE ur_class = 'REPORT_POSTING'",'',__METHOD__,__LINE__);
    while ( $r = $sche->fetchObject() )
    $reported[] = intval($r->ur_data);
  $sche->closeCursor();
  XFCache::put('simple','post_reported',$reported);
  $a = XF::sql_query("DELETE FROM ".XF::tbl('user_request')." WHERE ur_time < '".intval(XF::vault_query('uts')-XF::get_cfg('auth_activate_limit'))."' AND ur_class != 'REPORT_POSTING'",'',__METHOD__,__LINE__);
  $this->trace[] = 'removed '.$a.' entries from user requests';
  return true;
  }

}
$_t = new XFTask_prune_request();
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_private/task.prune_request.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');
  if ( !defined('__XF_ALLOW_TASK') )
  die('Running tasks has not been allowed by XF-Core!');

/**
* @package lbbackend
*/
class XFTask_prune_request extends XFTask {
public $version = 0x01;
protected $trace = array();

  public function setup(){
  return array(
  'default_interval'=>3600,
  'default_active'=>true
  );
  }

  public function execute(){
  $reported = array(0);
  $sche = XF::sql_query("SELECT ur_data_int FROM ".XF::tbl('user_request')." WHERE ur_class = 'REPORT_POSTING'",'',__METHOD__,__LINE__);
    while ( $r = $sche->fetchObject() )
    $reported[] = intval($r->ur_data_int);
  $sche->closeCursor();
  XFCache::put('simple','post_reported',$reported);
  $a = XF::sql_query("DELETE FROM ".XF::tbl('user_request')." WHERE ur_time < '".intval(XF::vault_query('uts')-XF::get_cfg('auth_activate_limit'))."' AND ur_class != 'REPORT_POSTING'",'',__METHOD__,__LINE__);
  $this->trace[] = 'removed '.$a.' entries from user requests';
  return true;
  }

}
$_t = new XFTask_prune_request();
?>
